# libpythonpro
Modulo de aprendizangem de construçao de projeto Python no curso Pytools

Nesse curso é ensinado como contribuir com projetos de código aberto.

Link para o curso [PythonPro](https://plataforma.dev.pro.br/)

Suportada versão 3 de Python

Para instalar:

'''console
python3 -m venv .venv
.venv/scripts/activate
pip install -r requirements-dev.txt
'''

Para verificar a qualidade do código:
'''console
flake8
'''

Tópicos a serem abordados:
 1. Git
 2. Virtualenvdist 
 3. Pip